Struct aws_sdk_codebuild::input::delete_report_group_input::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for DeleteReportGroupInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn delete_reports(self, input: bool) -> Self
pub fn delete_reports(self, input: bool) -> Self
If true, deletes any reports that belong to a report group before deleting the report group.
If false, you must delete any reports in the report group. Use ListReportsForReportGroup to get the reports in a report group. Use DeleteReport to delete the reports. If you call DeleteReportGroup for a report group that contains one or more reports, an exception is thrown.
sourcepub fn set_delete_reports(self, input: Option<bool>) -> Self
pub fn set_delete_reports(self, input: Option<bool>) -> Self
If true, deletes any reports that belong to a report group before deleting the report group.
If false, you must delete any reports in the report group. Use ListReportsForReportGroup to get the reports in a report group. Use DeleteReport to delete the reports. If you call DeleteReportGroup for a report group that contains one or more reports, an exception is thrown.
sourcepub fn build(self) -> Result<DeleteReportGroupInput, BuildError>
pub fn build(self) -> Result<DeleteReportGroupInput, BuildError>
Consumes the builder and constructs a DeleteReportGroupInput.