pub struct Builder { /* private fields */ }Expand description
A builder for ImportSourceCredentialsInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn username(self, input: impl Into<String>) -> Self
pub fn username(self, input: impl Into<String>) -> Self
The Bitbucket username when the authType is BASIC_AUTH. This parameter is not valid for other types of source providers or connections.
sourcepub fn set_username(self, input: Option<String>) -> Self
pub fn set_username(self, input: Option<String>) -> Self
The Bitbucket username when the authType is BASIC_AUTH. This parameter is not valid for other types of source providers or connections.
sourcepub fn token(self, input: impl Into<String>) -> Self
pub fn token(self, input: impl Into<String>) -> Self
For GitHub or GitHub Enterprise, this is the personal access token. For Bitbucket, this is the app password.
sourcepub fn set_token(self, input: Option<String>) -> Self
pub fn set_token(self, input: Option<String>) -> Self
For GitHub or GitHub Enterprise, this is the personal access token. For Bitbucket, this is the app password.
sourcepub fn server_type(self, input: ServerType) -> Self
pub fn server_type(self, input: ServerType) -> Self
The source provider used for this project.
sourcepub fn set_server_type(self, input: Option<ServerType>) -> Self
pub fn set_server_type(self, input: Option<ServerType>) -> Self
The source provider used for this project.
sourcepub fn auth_type(self, input: AuthType) -> Self
pub fn auth_type(self, input: AuthType) -> Self
The type of authentication used to connect to a GitHub, GitHub Enterprise, or Bitbucket repository. An OAUTH connection is not supported by the API and must be created using the CodeBuild console.
sourcepub fn set_auth_type(self, input: Option<AuthType>) -> Self
pub fn set_auth_type(self, input: Option<AuthType>) -> Self
The type of authentication used to connect to a GitHub, GitHub Enterprise, or Bitbucket repository. An OAUTH connection is not supported by the API and must be created using the CodeBuild console.
sourcepub fn should_overwrite(self, input: bool) -> Self
pub fn should_overwrite(self, input: bool) -> Self
Set to false to prevent overwriting the repository source credentials. Set to true to overwrite the repository source credentials. The default value is true.
sourcepub fn set_should_overwrite(self, input: Option<bool>) -> Self
pub fn set_should_overwrite(self, input: Option<bool>) -> Self
Set to false to prevent overwriting the repository source credentials. Set to true to overwrite the repository source credentials. The default value is true.
sourcepub fn build(self) -> Result<ImportSourceCredentialsInput, BuildError>
pub fn build(self) -> Result<ImportSourceCredentialsInput, BuildError>
Consumes the builder and constructs a ImportSourceCredentialsInput.