Struct aws_sdk_codebuild::input::CreateWebhookInput
source · #[non_exhaustive]pub struct CreateWebhookInput { /* private fields */ }Implementations
sourceimpl CreateWebhookInput
impl CreateWebhookInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateWebhook, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateWebhook, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<CreateWebhook>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture CreateWebhookInput.
sourceimpl CreateWebhookInput
impl CreateWebhookInput
sourcepub fn project_name(&self) -> Option<&str>
pub fn project_name(&self) -> Option<&str>
The name of the CodeBuild project.
sourcepub fn branch_filter(&self) -> Option<&str>
pub fn branch_filter(&self) -> Option<&str>
A regular expression used to determine which repository branches are built when a webhook is triggered. If the name of a branch matches the regular expression, then it is built. If branchFilter is empty, then all branches are built.
It is recommended that you use filterGroups instead of branchFilter.
sourcepub fn filter_groups(&self) -> Option<&[Vec<WebhookFilter>]>
pub fn filter_groups(&self) -> Option<&[Vec<WebhookFilter>]>
An array of arrays of WebhookFilter objects used to determine which webhooks are triggered. At least one WebhookFilter in the array must specify EVENT as its type.
For a build to be triggered, at least one filter group in the filterGroups array must pass. For a filter group to pass, each of its filters must pass.
sourcepub fn build_type(&self) -> Option<&WebhookBuildType>
pub fn build_type(&self) -> Option<&WebhookBuildType>
Specifies the type of build this webhook will trigger.