#[non_exhaustive]pub struct ListBuildBatchesForProjectInput { /* private fields */ }Implementations
sourceimpl ListBuildBatchesForProjectInput
impl ListBuildBatchesForProjectInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListBuildBatchesForProject, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListBuildBatchesForProject, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<ListBuildBatchesForProject>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListBuildBatchesForProjectInput.
sourceimpl ListBuildBatchesForProjectInput
impl ListBuildBatchesForProjectInput
sourcepub fn project_name(&self) -> Option<&str>
pub fn project_name(&self) -> Option<&str>
The name of the project.
sourcepub fn filter(&self) -> Option<&BuildBatchFilter>
pub fn filter(&self) -> Option<&BuildBatchFilter>
A BuildBatchFilter object that specifies the filters for the search.
sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return.
sourcepub fn sort_order(&self) -> Option<&SortOrderType>
pub fn sort_order(&self) -> Option<&SortOrderType>
Specifies the sort order of the returned items. Valid values include:
-
ASCENDING: List the batch build identifiers in ascending order by identifier. -
DESCENDING: List the batch build identifiers in descending order by identifier.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The nextToken value returned from a previous call to ListBuildBatchesForProject. This specifies the next item to return. To return the beginning of the list, exclude this parameter.