Struct aws_sdk_codebuild::input::ListBuildBatchesInput
source · #[non_exhaustive]pub struct ListBuildBatchesInput { /* private fields */ }Implementations
sourceimpl ListBuildBatchesInput
impl ListBuildBatchesInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListBuildBatches, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListBuildBatches, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<ListBuildBatches>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListBuildBatchesInput.
sourceimpl ListBuildBatchesInput
impl ListBuildBatchesInput
sourcepub fn filter(&self) -> Option<&BuildBatchFilter>
pub fn filter(&self) -> Option<&BuildBatchFilter>
A BuildBatchFilter object that specifies the filters for the search.
sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return.
sourcepub fn sort_order(&self) -> Option<&SortOrderType>
pub fn sort_order(&self) -> Option<&SortOrderType>
Specifies the sort order of the returned items. Valid values include:
-
ASCENDING: List the batch build identifiers in ascending order by identifier. -
DESCENDING: List the batch build identifiers in descending order by identifier.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The nextToken value returned from a previous call to ListBuildBatches. This specifies the next item to return. To return the beginning of the list, exclude this parameter.