Struct aws_sdk_codebuild::input::UpdateWebhookInput
source · #[non_exhaustive]pub struct UpdateWebhookInput { /* private fields */ }Implementations
sourceimpl UpdateWebhookInput
impl UpdateWebhookInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateWebhook, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateWebhook, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<UpdateWebhook>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateWebhookInput.
sourceimpl UpdateWebhookInput
impl UpdateWebhookInput
sourcepub fn project_name(&self) -> Option<&str>
pub fn project_name(&self) -> Option<&str>
The name of the CodeBuild project.
sourcepub fn branch_filter(&self) -> Option<&str>
pub fn branch_filter(&self) -> Option<&str>
A regular expression used to determine which repository branches are built when a webhook is triggered. If the name of a branch matches the regular expression, then it is built. If branchFilter is empty, then all branches are built.
It is recommended that you use filterGroups instead of branchFilter.
sourcepub fn rotate_secret(&self) -> bool
pub fn rotate_secret(&self) -> bool
A boolean value that specifies whether the associated GitHub repository's secret token should be updated. If you use Bitbucket for your repository, rotateSecret is ignored.
sourcepub fn filter_groups(&self) -> Option<&[Vec<WebhookFilter>]>
pub fn filter_groups(&self) -> Option<&[Vec<WebhookFilter>]>
An array of arrays of WebhookFilter objects used to determine if a webhook event can trigger a build. A filter group must contain at least one EVENT WebhookFilter.
sourcepub fn build_type(&self) -> Option<&WebhookBuildType>
pub fn build_type(&self) -> Option<&WebhookBuildType>
Specifies the type of build this webhook will trigger.