Struct aws_sdk_codebuild::model::cloud_watch_logs_config::Builder
source · [−]pub struct Builder { /* private fields */ }Expand description
A builder for CloudWatchLogsConfig.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn status(self, input: LogsConfigStatusType) -> Self
pub fn status(self, input: LogsConfigStatusType) -> Self
The current status of the logs in CloudWatch Logs for a build project. Valid values are:
-
ENABLED: CloudWatch Logs are enabled for this build project. -
DISABLED: CloudWatch Logs are not enabled for this build project.
sourcepub fn set_status(self, input: Option<LogsConfigStatusType>) -> Self
pub fn set_status(self, input: Option<LogsConfigStatusType>) -> Self
The current status of the logs in CloudWatch Logs for a build project. Valid values are:
-
ENABLED: CloudWatch Logs are enabled for this build project. -
DISABLED: CloudWatch Logs are not enabled for this build project.
sourcepub fn group_name(self, input: impl Into<String>) -> Self
pub fn group_name(self, input: impl Into<String>) -> Self
The group name of the logs in CloudWatch Logs. For more information, see Working with Log Groups and Log Streams.
sourcepub fn set_group_name(self, input: Option<String>) -> Self
pub fn set_group_name(self, input: Option<String>) -> Self
The group name of the logs in CloudWatch Logs. For more information, see Working with Log Groups and Log Streams.
sourcepub fn stream_name(self, input: impl Into<String>) -> Self
pub fn stream_name(self, input: impl Into<String>) -> Self
The prefix of the stream name of the CloudWatch Logs. For more information, see Working with Log Groups and Log Streams.
sourcepub fn set_stream_name(self, input: Option<String>) -> Self
pub fn set_stream_name(self, input: Option<String>) -> Self
The prefix of the stream name of the CloudWatch Logs. For more information, see Working with Log Groups and Log Streams.
sourcepub fn build(self) -> CloudWatchLogsConfig
pub fn build(self) -> CloudWatchLogsConfig
Consumes the builder and constructs a CloudWatchLogsConfig.