Struct aws_sdk_codebuild::model::CodeCoverage
source · [−]#[non_exhaustive]pub struct CodeCoverage { /* private fields */ }Expand description
Contains code coverage report information.
Line coverage measures how many statements your tests cover. A statement is a single instruction, not including comments, conditionals, etc.
Branch coverage determines if your tests cover every possible branch of a control structure, such as an if or case statement.
Implementations
sourceimpl CodeCoverage
impl CodeCoverage
sourcepub fn report_arn(&self) -> Option<&str>
pub fn report_arn(&self) -> Option<&str>
The ARN of the report.
sourcepub fn line_coverage_percentage(&self) -> Option<f64>
pub fn line_coverage_percentage(&self) -> Option<f64>
The percentage of lines that are covered by your tests.
sourcepub fn lines_covered(&self) -> Option<i32>
pub fn lines_covered(&self) -> Option<i32>
The number of lines that are covered by your tests.
sourcepub fn lines_missed(&self) -> Option<i32>
pub fn lines_missed(&self) -> Option<i32>
The number of lines that are not covered by your tests.
sourcepub fn branch_coverage_percentage(&self) -> Option<f64>
pub fn branch_coverage_percentage(&self) -> Option<f64>
The percentage of branches that are covered by your tests.
sourcepub fn branches_covered(&self) -> Option<i32>
pub fn branches_covered(&self) -> Option<i32>
The number of conditional branches that are covered by your tests.
sourcepub fn branches_missed(&self) -> Option<i32>
pub fn branches_missed(&self) -> Option<i32>
The number of conditional branches that are not covered by your tests.
sourceimpl CodeCoverage
impl CodeCoverage
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture CodeCoverage.