Struct aws_sdk_codebuild::model::webhook::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for Webhook.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn payload_url(self, input: impl Into<String>) -> Self
pub fn payload_url(self, input: impl Into<String>) -> Self
The CodeBuild endpoint where webhook events are sent.
sourcepub fn set_payload_url(self, input: Option<String>) -> Self
pub fn set_payload_url(self, input: Option<String>) -> Self
The CodeBuild endpoint where webhook events are sent.
sourcepub fn secret(self, input: impl Into<String>) -> Self
pub fn secret(self, input: impl Into<String>) -> Self
The secret token of the associated repository.
A Bitbucket webhook does not support secret.
sourcepub fn set_secret(self, input: Option<String>) -> Self
pub fn set_secret(self, input: Option<String>) -> Self
The secret token of the associated repository.
A Bitbucket webhook does not support secret.
sourcepub fn branch_filter(self, input: impl Into<String>) -> Self
pub fn branch_filter(self, input: impl Into<String>) -> Self
A regular expression used to determine which repository branches are built when a webhook is triggered. If the name of a branch matches the regular expression, then it is built. If branchFilter is empty, then all branches are built.
It is recommended that you use filterGroups instead of branchFilter.
sourcepub fn set_branch_filter(self, input: Option<String>) -> Self
pub fn set_branch_filter(self, input: Option<String>) -> Self
A regular expression used to determine which repository branches are built when a webhook is triggered. If the name of a branch matches the regular expression, then it is built. If branchFilter is empty, then all branches are built.
It is recommended that you use filterGroups instead of branchFilter.
sourcepub fn filter_groups(self, input: Vec<WebhookFilter>) -> Self
pub fn filter_groups(self, input: Vec<WebhookFilter>) -> Self
Appends an item to filter_groups.
To override the contents of this collection use set_filter_groups.
An array of arrays of WebhookFilter objects used to determine which webhooks are triggered. At least one WebhookFilter in the array must specify EVENT as its type.
For a build to be triggered, at least one filter group in the filterGroups array must pass. For a filter group to pass, each of its filters must pass.
sourcepub fn set_filter_groups(self, input: Option<Vec<Vec<WebhookFilter>>>) -> Self
pub fn set_filter_groups(self, input: Option<Vec<Vec<WebhookFilter>>>) -> Self
An array of arrays of WebhookFilter objects used to determine which webhooks are triggered. At least one WebhookFilter in the array must specify EVENT as its type.
For a build to be triggered, at least one filter group in the filterGroups array must pass. For a filter group to pass, each of its filters must pass.
sourcepub fn build_type(self, input: WebhookBuildType) -> Self
pub fn build_type(self, input: WebhookBuildType) -> Self
Specifies the type of build this webhook will trigger.
sourcepub fn set_build_type(self, input: Option<WebhookBuildType>) -> Self
pub fn set_build_type(self, input: Option<WebhookBuildType>) -> Self
Specifies the type of build this webhook will trigger.
sourcepub fn last_modified_secret(self, input: DateTime) -> Self
pub fn last_modified_secret(self, input: DateTime) -> Self
A timestamp that indicates the last time a repository's secret token was modified.
sourcepub fn set_last_modified_secret(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_secret(self, input: Option<DateTime>) -> Self
A timestamp that indicates the last time a repository's secret token was modified.