pub struct Builder { /* private fields */ }Expand description
A builder for DescribeCodeCoveragesOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
If there are more items to return, this contains a token that is passed to a subsequent call to DescribeCodeCoverages to retrieve the next set of items.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
If there are more items to return, this contains a token that is passed to a subsequent call to DescribeCodeCoverages to retrieve the next set of items.
sourcepub fn code_coverages(self, input: CodeCoverage) -> Self
pub fn code_coverages(self, input: CodeCoverage) -> Self
Appends an item to code_coverages.
To override the contents of this collection use set_code_coverages.
An array of CodeCoverage objects that contain the results.
sourcepub fn set_code_coverages(self, input: Option<Vec<CodeCoverage>>) -> Self
pub fn set_code_coverages(self, input: Option<Vec<CodeCoverage>>) -> Self
An array of CodeCoverage objects that contain the results.
sourcepub fn build(self) -> DescribeCodeCoveragesOutput
pub fn build(self) -> DescribeCodeCoveragesOutput
Consumes the builder and constructs a DescribeCodeCoveragesOutput.