Module aws_sdk_codebuild::error
source · Expand description
All error types that operations can return. Documentation on these types is copied from the model.
Modules
Structs
An Amazon Web Services service limit was exceeded for the calling Amazon Web Services account.
Error type for the
BatchDeleteBuilds operation.Error type for the
BatchGetBuildBatches operation.Error type for the
BatchGetBuilds operation.Error type for the
BatchGetProjects operation.Error type for the
BatchGetReportGroups operation.Error type for the
BatchGetReports operation.Error type for the
CreateProject operation.Error type for the
CreateReportGroup operation.Error type for the
CreateWebhook operation.Error type for the
DeleteBuildBatch operation.Error type for the
DeleteProject operation.Error type for the
DeleteReport operation.Error type for the
DeleteReportGroup operation.Error type for the
DeleteResourcePolicy operation.Error type for the
DeleteSourceCredentials operation.Error type for the
DeleteWebhook operation.Error type for the
DescribeCodeCoverages operation.Error type for the
DescribeTestCases operation.Error type for the
GetReportGroupTrend operation.Error type for the
GetResourcePolicy operation.Error type for the
ImportSourceCredentials operation.The input value that was provided is not valid.
Error type for the
InvalidateProjectCache operation.Error type for the
ListBuildBatches operation.Error type for the
ListBuildBatchesForProject operation.Error type for the
ListBuilds operation.Error type for the
ListBuildsForProject operation.Error type for the
ListCuratedEnvironmentImages operation.Error type for the
ListProjects operation.Error type for the
ListReportGroups operation.Error type for the
ListReports operation.Error type for the
ListReportsForReportGroup operation.Error type for the
ListSharedProjects operation.Error type for the
ListSharedReportGroups operation.Error type for the
ListSourceCredentials operation.There was a problem with the underlying OAuth provider.
Error type for the
PutResourcePolicy operation.The specified Amazon Web Services resource cannot be created, because an Amazon Web Services resource with the same settings already exists.
The specified Amazon Web Services resource cannot be found.
Error type for the
RetryBuildBatch operation.Error type for the
RetryBuild operation.Error type for the
StartBuildBatch operation.Error type for the
StartBuild operation.Error type for the
StopBuildBatch operation.Error type for the
StopBuild operation.An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Error type for the
UpdateProject operation.Error type for the
UpdateProjectVisibility operation.Error type for the
UpdateReportGroup operation.Error type for the
UpdateWebhook operation.Enums
Types of errors that can occur for the
BatchDeleteBuilds operation.Types of errors that can occur for the
BatchGetBuildBatches operation.Types of errors that can occur for the
BatchGetBuilds operation.Types of errors that can occur for the
BatchGetProjects operation.Types of errors that can occur for the
BatchGetReportGroups operation.Types of errors that can occur for the
BatchGetReports operation.Types of errors that can occur for the
CreateProject operation.Types of errors that can occur for the
CreateReportGroup operation.Types of errors that can occur for the
CreateWebhook operation.Types of errors that can occur for the
DeleteBuildBatch operation.Types of errors that can occur for the
DeleteProject operation.Types of errors that can occur for the
DeleteReport operation.Types of errors that can occur for the
DeleteReportGroup operation.Types of errors that can occur for the
DeleteResourcePolicy operation.Types of errors that can occur for the
DeleteSourceCredentials operation.Types of errors that can occur for the
DeleteWebhook operation.Types of errors that can occur for the
DescribeCodeCoverages operation.Types of errors that can occur for the
DescribeTestCases operation.Types of errors that can occur for the
GetReportGroupTrend operation.Types of errors that can occur for the
GetResourcePolicy operation.Types of errors that can occur for the
ImportSourceCredentials operation.Types of errors that can occur for the
InvalidateProjectCache operation.Types of errors that can occur for the
ListBuildBatches operation.Types of errors that can occur for the
ListBuildBatchesForProject operation.Types of errors that can occur for the
ListBuilds operation.Types of errors that can occur for the
ListBuildsForProject operation.Types of errors that can occur for the
ListCuratedEnvironmentImages operation.Types of errors that can occur for the
ListProjects operation.Types of errors that can occur for the
ListReportGroups operation.Types of errors that can occur for the
ListReports operation.Types of errors that can occur for the
ListReportsForReportGroup operation.Types of errors that can occur for the
ListSharedProjects operation.Types of errors that can occur for the
ListSharedReportGroups operation.Types of errors that can occur for the
ListSourceCredentials operation.Types of errors that can occur for the
PutResourcePolicy operation.Types of errors that can occur for the
RetryBuildBatch operation.Types of errors that can occur for the
RetryBuild operation.Types of errors that can occur for the
StartBuildBatch operation.Types of errors that can occur for the
StartBuild operation.Types of errors that can occur for the
StopBuildBatch operation.Types of errors that can occur for the
StopBuild operation.Types of errors that can occur for the
UpdateProject operation.Types of errors that can occur for the
UpdateProjectVisibility operation.Types of errors that can occur for the
UpdateReportGroup operation.Types of errors that can occur for the
UpdateWebhook operation.